#!/bin/sh

#***************************************************************************
#                 setup.sh   -  Cloxten setup shell script.
#                            -------------------
#   copyright            : (C) 2002 Alberto Lohmann
#   email                : lohmann@users.sf.net
#   app. url             : http://cloxten.sf.net
#   project url          : http://sf.net/projects/cloxten
#***************************************************************************

#***************************************************************************
#                                                                          *
#   This program is free software; you can redistribute it and/or modify   *
#   it under the terms of the GNU General Public License as published by   *
#   the Free Software Foundation; either version 2 of the License, or      *
#   (at your option) any later version.                                    *
#                                                                          *
#***************************************************************************

#  * This file is part of Cloxten program.


#  Exit status:
#
#      General:
#        0 - Success installation or uninstallation without pixmaps.
#        1 - User does not have write permission in INSTALL_DIR.
#        2 - Invalid input option (install/uninstall).
#        3 - Success installation or uninstallation with pixmaps.
#        4 - Success installation or uninstallation without pixmaps.
#            Invalid input option (pixmaps).
#        5 - Library libqt 2 not found.
#        6 - Library liqtintf 2 not found.
#        7 - Aborted by user.
#
#      Install:
#       10 - 'cloxten.bin' can't be installed. File not found.
#       20 - 'cloxten' can't be installed. File not found.
#       30 - 'doctordoc' can't be installed. File not found.
#       40 - 'cloxten16x16.xpm' can't be installed.
#       50 - 'cloxten32x32.xpm' can't be installed.
#
#      Uninstall:
#       60 - 'cloxten.bin' can't be uninstalled.
#       70 - 'cloxten' can't be uninstalled.
#       80 - 'doctordoc' can't be uninstalled.
#       90 - 'cloxten16x16.xpm' can't be uninstalled.
#      100 - 'cloxten32x32.xpm' can't be uninstalled.



#  I M P O R T A N T:
#
#  Please, check the install/uninstall directories below.
#  Write permission is required.
INSTALL_DIR=/usr/bin
PIXMAPS_DIR=/usr/share/pixmaps
USR_LIB_PATH=/usr/lib

# Verify write permission in INSTALL_DIR.
test -w $INSTALL_DIR;
RETVAL=$?;

case $RETVAL in
        1)
          echo -n "Permission denied in $INSTALL_DIR for user ";
          whoami;
          exit 1;;
esac;


# Check for required library:libqt.so.2 (the Qt library).
test -e $USR_LIB_PATH/libqt.so.2;
RETVAL=$?;

case $RETVAL in
        1)
          echo "The QT Library not found. I'm looking for file libqt.so.2 or a symbolic link ";
          echo "with this name. Please, check your installation and try again.";
          echo "You can obtain this file in Cloxten project page at:";
          echo "http://sourceforge.net/projects/cloxten";
          exit 5;;
esac;


# Check for required library: libqtintf.so.2 (the Qt interface library).
test -e $USR_LIB_PATH/libqtintf-6.5-qt2.3.so;
RETVAL=$?;

case $RETVAL in
        1)
          echo "The Qt interface library not found. I'm looking for file libqtintf-6.5-qt2.3.so";
          echo "or a symbolic link with this name. Please, check your installation and try";
          echo "again.";
          echo "You can obtain this file in Cloxten project page at:";
          echo "http://sourceforge.net/projects/cloxten";
          exit 6;;
esac;


echo "What do you want to do. "
echo "Install Cloxten or uninstall it? (i/u)"
read QUEST

case $QUEST in
        i | I)
          test -e ./cloxten.bin;
          case $? in
            0) cp ./cloxten.bin $INSTALL_DIR;;
            1) echo "File cloxten.bin not found. Exiting...";
               exit 10;;
          esac;

          test -e ./cloxten;
          case $? in
            0) cp ./cloxten $INSTALL_DIR;;
            1) echo "File cloxten not found. Exiting...";
               exit 20;;
          esac;

          test -e ./doctordoc;
          case $? in
            0) cp ./doctordoc $INSTALL_DIR;;
            1) echo "File doctordoc not found. Exiting...";
               exit 30;;
          esac;

          echo "Cloxten successly installed in $INSTALL_DIR";
          echo "When Setup is finished, type 'cloxten' to run it.";
          echo "";
          echo -n "Do you want to install Cloxten's icons (y/n)";
          read QUEST;

          case $QUEST in
                y | Y)
                  # Verify write permission in PIXMAPS_DIR.
                  test -w $PIXMAPS_DIR;
                  RETVAL=$?;

                  case $RETVAL in
                        0)
                          test -e ./pixmaps/cloxten16x16.xpm;
                          case $? in
                            0) cp ./pixmaps/cloxten16x16.xpm $PIXMAPS_DIR;;
                            1) echo "File './pixmaps/cloxten16x16.xpm' not found. Exiting...";
                               exit 40;;
                          esac;

                          test -e ./pixmaps/cloxten32x32.xpm;
                          case $? in
                            0) cp ./pixmaps/cloxten32x32.xpm $PIXMAPS_DIR;;
                            1) echo "File './pixmaps/cloxten32x32.xpm' not found. Exiting...";
                               exit 50;;
                          esac;

                          echo "Cloxten icons successly installed in $PIXMAPS_DIR";
                          exit 3;;

                        1)
                          echo -n "Permission denied in $PIXMAPS_DIR for user ";
                          whoami;
                          echo "Please, edit PIXMAPS_DIR in setup.sh and try again or copy icons in ./pixmaps";
                          echo "directory into another one by yourself."
                          exit 0;
                          ;;
                  esac;
                  ;;

                n | N)
                  exit 0;;
          esac;

          echo "Not a valid input. Cloxten's icons not installed.";

          exit 4;;

        u | U)
          rm -f $INSTALL_DIR/cloxten.bin;
          test -e $INSTALL_DIR/cloxten.bin;
          case $? in
            0) echo "Can't remove $INSTALL_DIR/cloxten.bin. Exiting...";
               exit 60;;
          esac;

          rm -f $INSTALL_DIR/cloxten;
          test -e $INSTALL_DIR/cloxten;
          case $? in
            0) echo "Can't remove $INSTALL_DIR/cloxten. Exiting...";
               exit 70;;
          esac;

          rm -f $INSTALL_DIR/doctordoc;
          test -e $INSTALL_DIR/cloxten.bin;
          case $? in
            0) echo "Can't remove $INSTALL_DIR/doctordoc. Exiting...";
               exit 80;;
          esac;

          rm -f $PIXMAPS_DIR/cloxten16x16.xpm;
          test -e $PIXMAPS_DIR/cloxten16x16.xpm;
          case $? in
            0) echo "Can't remove $PIXMAPS_DIR/cloxten16x16.xpm. Exiting...";
               exit 90;;
          esac;

          rm -f $PIXMAPS_DIR/cloxten32x32.xpm;
          test -e $PIXMAPS_DIR/cloxten32x32.xpm;
          case $? in
            0) echo "Can't remove $PIXMAPS_DIR/cloxten32x32.xpm. Exiting...";
               exit 100;;
          esac;

          echo "Cloxten successly uninstalled.";
          exit 0;;
esac

echo "Not a valid option."

exit 2;

# END.

